package App::seq::pl;

our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
our $DATE = '2021-07-17'; # DATE
our $DIST = 'App-seq-pl'; # DIST
our $VERSION = '0.002'; # VERSION

1;
# ABSTRACT: Like seq, but with Perl extras

__END__

=pod

=encoding UTF-8

=head1 NAME

App::seq::pl - Like seq, but with Perl extras

=head1 VERSION

This document describes version 0.002 of App::seq::pl (from Perl distribution App-seq-pl), released on 2021-07-17.

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/App-seq-pl>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-App-seq-pl>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-seq-pl>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2021, 2016 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
